@@ -1,5 +1,5 @@
 /**
- * (C) 2007-20 - ntop.org and contributors
+ * (C) 2007-21 - ntop.org and contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,10 +16,21 @@
  *
  */
 
+
+#include <stddef.h>
+#include <stdint.h>
+
+#include "portable_endian.h"
+
+
 void pearson_hash_256 (uint8_t *out, const uint8_t *in, size_t len);
 
 void pearson_hash_128 (uint8_t *out, const uint8_t *in, size_t len);
 
+uint64_t pearson_hash_64 (const uint8_t *in, size_t len);
+
+uint32_t pearson_hash_32 (const uint8_t *in, size_t len);
+
 uint16_t pearson_hash_16 (const uint8_t *in, size_t len);
 
-void pearson_hash_init();
+void pearson_hash_init ();
